==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Information/InfoArcCircleArea/ts/InfoArcCircleArea_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>InfoArcCircleArea</name>
    <message>
        <location filename="../InfoArcCircleArea.js" line="+70"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location line="+233"/>
        <location line="+21"/>
        <location line="+24"/>
        <location line="+21"/>
        <location line="+22"/>
        <location line="+22"/>
        <source>Area</source>
        <translation>エリア</translation>
    </message>
    <message>
        <location line="-108"/>
        <location line="+66"/>
        <source>Circumference</source>
        <translation>外周</translation>
    </message>
    <message>
        <location line="-37"/>
        <location line="+24"/>
        <source>Ellipse arc area:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-23"/>
        <location line="+24"/>
        <location line="+43"/>
        <location line="+22"/>
        <source>arc length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-88"/>
        <location line="+67"/>
        <source>chord:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-52"/>
        <source>Distance</source>
        <translation>距離</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>distance:</source>
        <translation>距離:</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>radius:</source>
        <translation>半径:</translation>
    </message>
    <message>
        <location line="-9"/>
        <source>Radius</source>
        <translation>半径</translation>
    </message>
    <message>
        <location line="-104"/>
        <source>Circle area:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-245"/>
        <source>Choose arc, circle, ellipse or elliptical arc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+246"/>
        <location line="+67"/>
        <source>circumference:</source>
        <translation></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Ellipse area:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <location line="+22"/>
        <source>Arc area:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.ui" line="+17"/>
        <source>Mode:</source>
        <translation>モード:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Calculate Area of Sector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Calculate Area of Segment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Add:</source>
        <translation>追加:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Add entities to drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>エンティティ</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.js" line="-96"/>
        <location line="+67"/>
        <location filename="../InfoArcCircleArea.ui" line="+13"/>
        <source>Chord</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.ui" line="+13"/>
        <source>Add lengths/circumference to drawing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.js" line="-68"/>
        <location line="+24"/>
        <location line="+43"/>
        <location line="+22"/>
        <location filename="../InfoArcCircleArea.ui" line="+3"/>
        <source>Length</source>
        <translation>長さ</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleAreaInit.js" line="+2"/>
        <source>Arc/Circle/Ellipse Area</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Information/InfoArcCircleArea/ts/InfoArcCircleArea_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>InfoArcCircleArea</name>
    <message>
        <location filename="../InfoArcCircleArea.js" line="+73"/>
        <source>Done</source>
        <translation>完了</translation>
    </message>
    <message>
        <location line="+233"/>
        <location line="+21"/>
        <location line="+24"/>
        <location line="+21"/>
        <location line="+22"/>
        <location line="+22"/>
        <source>Area</source>
        <translation>エリア</translation>
    </message>
    <message>
        <location line="-108"/>
        <location line="+66"/>
        <source>Circumference</source>
        <translation>外周</translation>
    </message>
    <message>
        <location line="-37"/>
        <location line="+24"/>
        <source>Ellipse arc area:</source>
        <translation>楕円弧面積:</translation>
    </message>
    <message>
        <location line="-23"/>
        <location line="+24"/>
        <location line="+43"/>
        <location line="+22"/>
        <source>arc length:</source>
        <translation>弧の長さ:</translation>
    </message>
    <message>
        <location line="-88"/>
        <location line="+67"/>
        <source>chord:</source>
        <translation>弦:</translation>
    </message>
    <message>
        <location line="-52"/>
        <source>Distance</source>
        <translation>距離</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>distance:</source>
        <translation>距離:</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>radius:</source>
        <translation>半径:</translation>
    </message>
    <message>
        <location line="-9"/>
        <source>Radius</source>
        <translation>半径</translation>
    </message>
    <message>
        <location line="-104"/>
        <source>Circle area:</source>
        <translation>円面積:</translation>
    </message>
    <message>
        <location line="-245"/>
        <source>Choose arc, circle, ellipse or elliptical arc</source>
        <translation>弧、円、楕円または楕円弧を選択して下さい</translation>
    </message>
    <message>
        <location line="+246"/>
        <location line="+67"/>
        <source>circumference:</source>
        <translation>外周:</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Ellipse area:</source>
        <translation>楕円面積:</translation>
    </message>
    <message>
        <location line="+22"/>
        <location line="+22"/>
        <source>Arc area:</source>
        <translation>弧面積:</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.ui" line="+17"/>
        <source>Mode:</source>
        <translation>モード:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Calculate Area of Sector</source>
        <translation>セクターの面積を計算</translation>
    </message>
    <message>
        <location line="-23"/>
        <source>Calculate Area of Segment</source>
        <translation>セグメントの面積を計算</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Add:</source>
        <translation>追加:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Add entities to drawing</source>
        <translation>図面にエンティティを追加</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>エンティティ</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.js" line="-96"/>
        <location line="+67"/>
        <location filename="../InfoArcCircleArea.ui" line="+13"/>
        <source>Chord</source>
        <translation>弦</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.ui" line="+13"/>
        <source>Add lengths/circumference to drawing</source>
        <translation>長さ/外周を図面に追加</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleArea.js" line="-68"/>
        <location line="+24"/>
        <location line="+43"/>
        <location line="+22"/>
        <location filename="../InfoArcCircleArea.ui" line="+3"/>
        <source>Length</source>
        <translation>長さ</translation>
    </message>
    <message>
        <location filename="../InfoArcCircleAreaInit.js" line="+2"/>
        <source>Arc/Circle/Ellipse Area</source>
        <translation>弧・円・楕円面積:</translation>
    </message>
</context>
</TS>
